# Implementation <> Validation Iteration
1. Review your implementation using Playwright (web) and Patrol (apps).
2. Ensure that your tests considers the design system and guidance. Refer to docs/02-design.
3. Ensure that your tests are written from the user workflow perspectives.
   - Adopt a user persona and think of the workflow step by step.
   - Generate the tests and metrics for each step, including the transitions between steps.
4. Give me a detailed checklist based on your tests so that I can validate it manually.
